@@ -10,6 +10,8 @@
 
 #include <QSharedPointer>
 
+#include "config-akregator.h"
+
 #include "akregator_export.h"
 
 namespace Akregator
@@ -22,7 +24,9 @@ class Storage;
 class FeedList;
 class FetchQueue;
 class FrameManager;
-
+#if HAVE_ACTIVITY_SUPPORT
+class ActivitiesManager;
+#endif
 class AKREGATOR_EXPORT Kernel
 {
 public:
@@ -30,16 +34,19 @@ public:
 
     ~Kernel();
 
-    Backend::Storage *storage();
+    [[nodiscard]] Backend::Storage *storage();
     void setStorage(Backend::Storage *storage);
 
     [[nodiscard]] QSharedPointer<FeedList> feedList() const;
     void setFeedList(const QSharedPointer<FeedList> &feedList);
 
-    FetchQueue *fetchQueue() const;
+    [[nodiscard]] FetchQueue *fetchQueue() const;
 
-    FrameManager *frameManager() const;
+    [[nodiscard]] FrameManager *frameManager() const;
 
+#if HAVE_ACTIVITY_SUPPORT
+    [[nodiscard]] ActivitiesManager *activitiesManager() const;
+#endif
 private:
     Kernel();
 
@@ -47,7 +54,10 @@ private:
 
     Backend::Storage *m_storage = nullptr;
     QSharedPointer<FeedList> m_feedList;
-    FetchQueue *m_fetchQueue = nullptr;
-    FrameManager *m_frameManager = nullptr;
+    FetchQueue *const m_fetchQueue;
+    FrameManager *const m_frameManager;
+#if HAVE_ACTIVITY_SUPPORT
+    ActivitiesManager *const mActivitiesManager;
+#endif
 };
 } // namespace Akregator
